@@ -91,10 +91,10 @@ our @EXPORT_OK = qw(
 
 =head2 hash_the_password
 
-Takes a request entity (hashref) - looks for a 'password' property.
-if it is present, hashes the password with a random salt - in effect,
-this replaces the password property with passhash+salt. If there is
-no password property, the function does nothing.
+Takes a request entity (hashref) - looks for a 'password' property.  If it
+is present, adds a random salt to the request entity and hashes the
+password with it.  If there is no password property, the function does
+nothing.
 
 =cut
 
@@ -154,16 +154,10 @@ sub pre_update_comparison {
     foreach my $prop (keys %$over) {
         if ( exists $obj->{$prop} ) {
             next if not defined $obj->{$prop} and not defined $over->{$prop};
-#            next if ( defined $obj->{$prop} and defined $over->{$prop} ) and ( $obj->{$prop} eq $over->{$prop} );
-#            if (
-#                 ( defined $obj->{$prop} and not defined $over->{$prop} ) or
-#                 ( not defined $obj->{$prop} and defined $over->{$prop} ) or
-#                 ( $obj->{$prop} ne $over->{$prop} ) 
-#               ) {
-                $log->debug( "pre_update_comparison: detected changed property $prop" );
-                $obj->{$prop} = $over->{$prop};
-                $c += 1;
-#            }
+            $log->debug( "pre_update_comparison: detected changed property $prop" );
+            # FIXME: how to test equality when we don't know the type?
+            $obj->{$prop} = $over->{$prop};
+            $c += 1;
         }
     }
     return $c;
